@@ -4,7 +4,6 @@ test_that("Y is tested and works", {
   expect_error(crossvalidationCP())
   expect_error(crossvalidationCP(Y = NULL))
   expect_error(crossvalidationCP(Y = "s"))
-  expect_error(crossvalidationCP(Y = rep("s", 20)))
   expect_error(crossvalidationCP(Y = as.list(rnorm(100))))
   expect_error(crossvalidationCP(Y = matrix(rnorm(100), 2, 50)))
   
@@ -34,17 +33,17 @@ test_that("fit is correct", {
   set.seed(4336L)
   testY <- rnorm(100)
   ret <- crossvalidationCP(Y = testY, output = "fit")$fit
-  compare <- list(cps = c(0, optimalPartitioning(Y = testY, param = 0L)[[1]], length(testY)))
+  compare <- list(cps = c(0, leastSquares(Y = testY, param = 0L)[[1]], length(testY)))
   expect_identical(ret, compare)
   
   testY <- c(rnorm(50), rnorm(50, 5))
   ret <- crossvalidationCP(Y = testY, output = "fit")$fit
-  compare <- list(cps = c(0, optimalPartitioning(Y = testY, param = 1L)[[1]], length(testY)))
+  compare <- list(cps = c(0, leastSquares(Y = testY, param = 1L)[[1]], length(testY)))
   expect_identical(ret, compare)
   
   testY <- c(rnorm(50), rnorm(50, 5), rnorm(50), rnorm(50, 5))
   ret <- crossvalidationCP(Y = testY, output = "fit")$fit
-  compare <- list(cps = c(0, optimalPartitioning(Y = testY, param = 3L)[[1]], length(testY)))
+  compare <- list(cps = c(0, leastSquares(Y = testY, param = 3L)[[1]], length(testY)))
   expect_identical(ret, compare)
 })
 
@@ -61,10 +60,10 @@ test_that("CV is correct", {
   expect_equal(ret[1], compare)
   
   ret <- crossvalidationCP(Y = testY, output = "detailed", folds = 2)$CV
-  # 2 == optimalPartitioning(Y = testY[-(0:49 * 2 + 1)], param = 1L)[[1]] -> 4
+  # 2 == leastSquares(Y = testY[-(0:49 * 2 + 1)], param = 1L)[[1]] -> 4
   compare <- criterionL1loss(testset = testY[0:1 * 2 + 1], estset = testY[0:1 * 2 + 2]) +
     criterionL1loss(testset = testY[2:49 * 2 + 1], estset = testY[2:49 * 2 + 2])
-  # 24 == optimalPartitioning(Y = testY[-(0:49 * 2 + 2)], param = 1L)[[1]] -> 47
+  # 24 == leastSquares(Y = testY[-(0:49 * 2 + 2)], param = 1L)[[1]] -> 47
   compare <- compare +
     criterionL1loss(testset = testY[0:22 * 2 + 2], estset = testY[0:23 * 2 + 1]) +
     criterionL1loss(testset = testY[23:49 * 2 + 2], estset = testY[24:49 * 2 + 1])
@@ -128,9 +127,9 @@ test_that("folds is tested and works", {
   testY <- c(1:50, rep(50, 50))
   ret <- crossvalidationCP(Y = testY, folds = list(c(3, 5, 8, 9, 12, 16, 20, 25, 30, 36, 39, 43, 50)),
                            output = "detailed")
-  compare <- list(cps = c(0, optimalPartitioning(Y = testY, param = 5L)[[1]], length(testY)))
+  compare <- list(cps = c(0, leastSquares(Y = testY, param = 5L)[[1]], length(testY)))
   expect_identical(ret$fit, compare)
-  # 38 == optimalPartitioning(Y = testY[-c(3, 5, 8, 9, 12, 16, 20, 25, 30, 36, 39, 43, 50)], param = 1L)[[1]] -> 32
+  # 38 == leastSquares(Y = testY[-c(3, 5, 8, 9, 12, 16, 20, 25, 30, 36, 39, 43, 50)], param = 1L)[[1]] -> 32
   # (1:100)[-c(3, 5, 8, 9, 12, 16, 20, 25, 30, 36, 39, 43, 50)][23]
   compare <- criterionL1loss(testset = testY[c(3, 5, 8, 9, 12, 16, 20, 25, 30)], 
                              estset = (1:32)[-c(3, 5, 8, 9, 12, 16, 20, 25, 30)]) +
@@ -140,7 +139,7 @@ test_that("folds is tested and works", {
 
 test_that("estimator is tested and works", {
   testY <- 1:100
-  expect_identical(crossvalidationCP(Y = testY, estimator = optimalPartitioning, output = "detailed"),
+  expect_identical(crossvalidationCP(Y = testY, estimator = leastSquares, output = "detailed"),
                    crossvalidationCP(Y = testY, output = "detailed"))
   
   expect_error(crossvalidationCP(Y = testY, estimator = 1))
@@ -228,39 +227,39 @@ test_that("estimator is tested and works", {
   expect_identical(ret, list(penalty = "SIC", Q = 20))
   
   
-  ret <- crossvalidationCP(Y = testY, estimator = smuce, output = "detailed", param = list(0.01, 0.05, 0.5), folds = 2)
-  retCompare <- smuce(Y = testY, param = 0.01)
-  compare <- list(cps = c(0, retCompare[[1]][[1]], length(testY)), value = retCompare$value[[1]])
-  expect_equal(ret$fit, compare)
-  
-  compareEst1 <- smuce(Y = testY[0:24 * 2 + 1], param = 0.01)
-  # 10, 13 == compareEst1$cps[[1]] -> 19, 25
-  compareEst2 <- smuce(Y = testY[0:24 * 2 + 2], param = list(0.01, 0.05, 0.5))
-  # 12 == compareEst2$cps[[1]] -> 24
-  compare <- criterionL1loss(testset = testY[0:8 * 2 + 2], value = compareEst1$value[[1]][[1]]) +
-    criterionL1loss(testset = testY[9:11 * 2 + 2], value = compareEst1$value[[1]][[2]]) +
-    criterionL1loss(testset = testY[12:24 * 2 + 2], value = compareEst1$value[[1]][[3]]) + 
-    criterionL1loss(testset = testY[0:11 * 2 + 1], value = compareEst2$value[[1]][[1]]) +
-    criterionL1loss(testset = testY[12:24 * 2 + 1], value = compareEst2$value[[1]][[2]])
-  expect_equal(ret$CV[1], compare)
+  # ret <- crossvalidationCP(Y = testY, estimator = smuce, output = "detailed", param = list(0.01, 0.05, 0.5), folds = 2)
+  # retCompare <- smuce(Y = testY, param = 0.01)
+  # compare <- list(cps = c(0, retCompare[[1]][[1]], length(testY)), value = retCompare$value[[1]])
+  # expect_equal(ret$fit, compare)
+  # 
+  # compareEst1 <- smuce(Y = testY[0:24 * 2 + 1], param = 0.01)
+  # # 10, 13 == compareEst1$cps[[1]] -> 19, 25
+  # compareEst2 <- smuce(Y = testY[0:24 * 2 + 2], param = list(0.01, 0.05, 0.5))
+  # # 12 == compareEst2$cps[[1]] -> 24
+  # compare <- criterionL1loss(testset = testY[0:8 * 2 + 2], value = compareEst1$value[[1]][[1]]) +
+  #   criterionL1loss(testset = testY[9:11 * 2 + 2], value = compareEst1$value[[1]][[2]]) +
+  #   criterionL1loss(testset = testY[12:24 * 2 + 2], value = compareEst1$value[[1]][[3]]) + 
+  #   criterionL1loss(testset = testY[0:11 * 2 + 1], value = compareEst2$value[[1]][[1]]) +
+  #   criterionL1loss(testset = testY[12:24 * 2 + 1], value = compareEst2$value[[1]][[2]])
+  # expect_equal(ret$CV[1], compare)
 
   
   set.seed(3955L)
   testY <- c(rnorm(25, 0, 0.1), rnorm(25, 10, 0.1))
-  ret <- crossvalidationCP(Y = testY, estimator = fdrseg, output = "detailed", param = list(0.01, 0.05), folds = 2)
-  retCompare <- fdrseg(Y = testY, param = 0.01)
-  compare <- list(cps = c(0, retCompare[[1]][[1]], length(testY)), value = retCompare$value[[1]])
-  expect_equal(ret$fit, compare)
-  
-  compareEst1 <- fdrseg(Y = testY[0:24 * 2 + 1], param = 0.01)
-  # 13 == compareEst1$cps[[1]] -> 25
-  compareEst2 <- fdrseg(Y = testY[0:24 * 2 + 2], param = list(0.05, 0.5, 0.01))
-  # 12 == compareEst2$cps[[1]] -> 24
-  compare <- criterionL1loss(testset = testY[0:11 * 2 + 2], value = compareEst1$value[[1]][[1]]) +
-    criterionL1loss(testset = testY[12:24 * 2 + 2], value = compareEst1$value[[1]][[2]]) + 
-    criterionL1loss(testset = testY[0:11 * 2 + 1], value = compareEst2$value[[3]][[1]]) +
-    criterionL1loss(testset = testY[12:24 * 2 + 1], value = compareEst2$value[[3]][[2]])
-  expect_equal(ret$CV[1], compare)
+  # ret <- crossvalidationCP(Y = testY, estimator = fdrseg, output = "detailed", param = list(0.01, 0.05), folds = 2)
+  # retCompare <- fdrseg(Y = testY, param = 0.01)
+  # compare <- list(cps = c(0, retCompare[[1]][[1]], length(testY)), value = retCompare$value[[1]])
+  # expect_equal(ret$fit, compare)
+  # 
+  # compareEst1 <- fdrseg(Y = testY[0:24 * 2 + 1], param = 0.01)
+  # # 13 == compareEst1$cps[[1]] -> 25
+  # compareEst2 <- fdrseg(Y = testY[0:24 * 2 + 2], param = list(0.05, 0.5, 0.01))
+  # # 12 == compareEst2$cps[[1]] -> 24
+  # compare <- criterionL1loss(testset = testY[0:11 * 2 + 2], value = compareEst1$value[[1]][[1]]) +
+  #   criterionL1loss(testset = testY[12:24 * 2 + 2], value = compareEst1$value[[1]][[2]]) + 
+  #   criterionL1loss(testset = testY[0:11 * 2 + 1], value = compareEst2$value[[3]][[1]]) +
+  #   criterionL1loss(testset = testY[12:24 * 2 + 1], value = compareEst2$value[[3]][[2]])
+  # expect_equal(ret$CV[1], compare)
   
   
   ret <- crossvalidationCP(Y = testY, estimator = wbs, output = "detailed", param = list(1.0, 1.3), folds = 2)
@@ -306,7 +305,7 @@ test_that("criterion is tested and works", {
   set.seed(969564L)
   testY <- c(rnorm(50), rnorm(50, 5), rnorm(50), rnorm(50, 5))
   ret <- crossvalidationCP(Y = testY, output = "fit", criterion = criterionL2loss)$fit
-  compare <- list(cps = c(0, optimalPartitioning(Y = testY, param = 3L)[[1]], length(testY)))
+  compare <- list(cps = c(0, leastSquares(Y = testY, param = 3L)[[1]], length(testY)))
   expect_identical(ret, compare)
 
   testY <- rnorm(100)
@@ -318,23 +317,23 @@ test_that("criterion is tested and works", {
     criterionMod(testset = testY[0:19 * 5 + 5], estset = testY[-(0:19 * 5 + 5)])
   expect_equal(ret[1], compare)
   
-  set.seed(3955L)
-  testY <- c(rnorm(25, 0, 0.1), rnorm(25, 10, 0.1))
-  ret <- crossvalidationCP(Y = testY, estimator = fdrseg, output = "detailed", param = list(0.01, 0.05), folds = 2,
-                           criterion = criterionMod)
-  retCompare <- fdrseg(Y = testY, param = 0.01)
-  compare <- list(cps = c(0, retCompare[[1]][[1]], length(testY)), value = retCompare$value[[1]])
-  expect_equal(ret$fit, compare)
-  
-  compareEst1 <- fdrseg(Y = testY[0:24 * 2 + 1], param = 0.01)
-  # 13 == compareEst1$cps[[1]] -> 25
-  compareEst2 <- fdrseg(Y = testY[0:24 * 2 + 2], param = list(0.05, 0.5, 0.01))
-  # 12 == compareEst2$cps[[1]] -> 24
-  compare <- criterionMod(testset = testY[0:11 * 2 + 2], value = compareEst1$value[[1]][[1]]) +
-    criterionMod(testset = testY[12:24 * 2 + 2], value = compareEst1$value[[1]][[2]]) + 
-    criterionMod(testset = testY[0:11 * 2 + 1], value = compareEst2$value[[3]][[1]]) +
-    criterionMod(testset = testY[12:24 * 2 + 1], value = compareEst2$value[[3]][[2]])
-  expect_equal(ret$CV[1], compare)
+  # set.seed(3955L)
+  # testY <- c(rnorm(25, 0, 0.1), rnorm(25, 10, 0.1))
+  # ret <- crossvalidationCP(Y = testY, estimator = fdrseg, output = "detailed", param = list(0.01, 0.05), folds = 2,
+  #                          criterion = criterionMod)
+  # retCompare <- fdrseg(Y = testY, param = 0.01)
+  # compare <- list(cps = c(0, retCompare[[1]][[1]], length(testY)), value = retCompare$value[[1]])
+  # expect_equal(ret$fit, compare)
+  # 
+  # compareEst1 <- fdrseg(Y = testY[0:24 * 2 + 1], param = 0.01)
+  # # 13 == compareEst1$cps[[1]] -> 25
+  # compareEst2 <- fdrseg(Y = testY[0:24 * 2 + 2], param = list(0.05, 0.5, 0.01))
+  # # 12 == compareEst2$cps[[1]] -> 24
+  # compare <- criterionMod(testset = testY[0:11 * 2 + 2], value = compareEst1$value[[1]][[1]]) +
+  #   criterionMod(testset = testY[12:24 * 2 + 2], value = compareEst1$value[[1]][[2]]) + 
+  #   criterionMod(testset = testY[0:11 * 2 + 1], value = compareEst2$value[[3]][[1]]) +
+  #   criterionMod(testset = testY[12:24 * 2 + 1], value = compareEst2$value[[3]][[2]])
+  # expect_equal(ret$CV[1], compare)
 })
 
 test_that("... is tested and works", {
@@ -410,16 +409,16 @@ test_that("folds == 'COPPS' is working", {
   expect_equal(suppressWarnings(crossvalidationCP(Y = testY, folds = "COPPS", output = "detailed", criterion = criterionMod,
                                                       estimator = binseg, param = list("SIC", 1e9))),
                    suppressWarnings(CVmod(Y = testY, output = "detailed", estimator = binseg, param = list("SIC", 1e9))))
-  set.seed(1987654)
-  ret <- crossvalidationCP(Y = testY, folds = "COPPS", output = "detailed", criterion = criterionL2loss,
-                           estimator = fdrseg, param = list(0.1, 0.2))
-  set.seed(1987654)
-  expect_equal(ret, COPPS(Y = testY, output = "detailed", estimator = fdrseg, param = list(0.1, 0.2)))
-
-  expect_equal(crossvalidationCP(Y = testY, folds = "COPPS", output = "detailed", criterion = criterionL2loss,
-                                     test = 1),
-                   COPPS(Y = testY, output = "detailed"))
-  expect_error(crossvalidationCP(Y = testY, folds = "COPPS", testset = 1:10))
+  # set.seed(1987654)
+  # ret <- crossvalidationCP(Y = testY, folds = "COPPS", output = "detailed", criterion = criterionL2loss,
+  #                          estimator = fdrseg, param = list(0.1, 0.2))
+  # set.seed(1987654)
+  # expect_equal(ret, COPPS(Y = testY, output = "detailed", estimator = fdrseg, param = list(0.1, 0.2)))
+  # 
+  # expect_equal(crossvalidationCP(Y = testY, folds = "COPPS", output = "detailed", criterion = criterionL2loss,
+  #                                    test = 1),
+  #                  COPPS(Y = testY, output = "detailed"))
+  # expect_error(crossvalidationCP(Y = testY, folds = "COPPS", testset = 1:10))
   
   testEstimator <- function(Y, param, testvalue, ...) {list(cps = list(10, 25, 40),
                                                             value = list(list(testvalue, testvalue),
@@ -462,60 +461,59 @@ test_that("criterion is tested and works if folds == 'COPPS'", {
   expect_equal(crossvalidationCP(Y = testY, output = "detailed", criterion = criterionMod, folds = "COPPS"),
                   CVmod(Y = testY, output = "detailed"))
   
-  set.seed(3955L)
-  testY <- c(rnorm(25, 0, 0.1), rnorm(25, 10, 0.1))
-  expect_equal(crossvalidationCP(Y = testY, estimator = fdrseg, output = "detailed", param = list(0.01, 0.05),
-                                     folds = "COPPS", criterion = criterionMod),
-                   CVmod(Y = testY, output = "detailed", estimator = fdrseg, param = list(0.01, 0.05)))
+  # set.seed(3955L)
+  # testY <- c(rnorm(25, 0, 0.1), rnorm(25, 10, 0.1))
+  # expect_equal(crossvalidationCP(Y = testY, estimator = fdrseg, output = "detailed", param = list(0.01, 0.05),
+  #                                    folds = "COPPS", criterion = criterionMod),
+  #                  CVmod(Y = testY, output = "detailed", estimator = fdrseg, param = list(0.01, 0.05)))
 })
 
 test_that("VfoldCV is working", {
   expect_error(VfoldCV())
   expect_error(VfoldCV(Y = NULL))
   expect_error(VfoldCV(Y = "s"))
-  expect_error(VfoldCV(Y = rep("s", 20)))
   expect_error(VfoldCV(Y = as.list(rnorm(100))))
   expect_error(VfoldCV(Y = matrix(rnorm(100), 2, 50)))
   
   set.seed(267L)
   testY <- rnorm(100)
   expect_identical(VfoldCV(Y = testY, output = "detailed"),
-                   crossvalidationCP(Y = testY, output = "detailed"))
+                   crossvalidationCP(Y = testY, output = "detailed", param = 8L))
   
   expect_error(VfoldCV(Y = testY, output = c("param", "fit")))
   expect_equal(VfoldCV(Y = testY, output = "detailed")$param,
-                   crossvalidationCP(Y = testY))
+                   crossvalidationCP(Y = testY, param = 8L))
   
   set.seed(9653L)
   testY <- c(rnorm(50), rnorm(50, 5), rnorm(50), rnorm(50, 5))
   expect_equal(VfoldCV(Y = testY, output = "detailed"),
-                   crossvalidationCP(Y = testY, output = "detailed"))
+                   crossvalidationCP(Y = testY, output = "detailed", param = 8L))
   
   expect_error(suppressWarnings(VfoldCV(Y = testY, Kmax = "test")))
-  expect_equal(VfoldCV(Y = testY, output = "detailed", Kmax = 2L),
+  expect_equal(VfoldCV(Y = testY, output = "detailed", Kmax = 2L, adaptiveKmax = FALSE),
                    crossvalidationCP(Y = testY, output = "detailed", param = as.list(0:2)))
   
   expect_error(VfoldCV(Y = testY, V = matrix(1:4, 2, 2)))
   expect_equal(VfoldCV(Y = testY, output = "detailed", V = 2L),
-                   crossvalidationCP(Y = testY, output = "detailed", folds = 2L))
+                   crossvalidationCP(Y = testY, output = "detailed", folds = 2L, param = 8L))
   
   testEstimator <- function(Y, param, ...) {as.list(rep(5, 7))}
   expect_error(VfoldCV(Y = testY, estimator = testEstimator))
   
   testEstimator <- function(Y, param, ...) {list(cps = list(10, 25, 40),
                                                  value = list(as.list(0:1), as.list(0:1), as.list(0:1)))}
-  expect_equal(VfoldCV(Y = testY, output = "detailed", V = 2L, Kmax = 2L, estimator = testEstimator),
+  expect_equal(VfoldCV(Y = testY, output = "detailed", V = 2L, Kmax = 2L, estimator = testEstimator, adaptiveKmax = FALSE),
                    crossvalidationCP(Y = testY, output = "detailed", folds = 2L, param = 2L, estimator = testEstimator))
   
   testCriterion <- function(testset, estset, value, ...) {1:2}
   expect_warning(VfoldCV(Y = testY, criterion = testCriterion))
   expect_equal(VfoldCV(Y = testY, output = "detailed", criterion = criterionL2loss),
-                   crossvalidationCP(Y = testY, output = "detailed", criterion = criterionL2loss))
-  expect_equal(VfoldCV(Y = testY, output = "detailed", V = 2L, criterion = criterionMod),
-                   crossvalidationCP(Y = testY, output = "detailed", folds = 2L, criterion = criterionMod))
+                   crossvalidationCP(Y = testY, output = "detailed", criterion = criterionL2loss, param = 8L))
+  expect_equal(VfoldCV(Y = testY, output = "detailed", V = 2L, criterion = criterionMod, adaptiveKmax = FALSE),
+                   crossvalidationCP(Y = testY, output = "detailed", folds = 2L, criterion = criterionMod, param = 8L))
   
   expect_equal(VfoldCV(Y = testY, output = "detailed", test = 1L),
-                   crossvalidationCP(Y = testY, output = "detailed"))
+                   crossvalidationCP(Y = testY, output = "detailed", param = 8L))
   expect_error(VfoldCV(Y = testY, output = "detailed", testset = 1))
   
   testCriterion <- function(value, testcrit, ...) {as.numeric(value != testcrit)}
@@ -524,5 +522,5 @@ test_that("VfoldCV is working", {
                                                                          list(testvalue, testvalue)))}
   expect_identical(VfoldCV(Y = testY, output = "detailed", Kmax = 2L,
                            estimator = testEstimator, testvalue = 10,
-                           criterion = testCriterion, testcrit = 10)$CV, c(10, 10, 0))
+                           criterion = testCriterion, testcrit = 10, adaptiveKmax = FALSE)$CV, c(10, 10, 0))
 })
